#!/bin/bash
#####################################################################################################
# This Script will start/stop CumulusMX (http://sandaysoft.com/) if already started/stopped
# Copy this script into the CumulusMX installation Folder and start it with sudo ./cumulusmx.sh
# If you want CumulusMX to be restarted call it with -r (sudo ./cumulusmx.sh -r)
# For more information read http://sandaysoft.com/forum/viewtopic.php?f=27&t=13767
#
# You can make sheduled ZIP Backups by using this line in cron: sudo /CumulusMX/cumulusmx.sh -b -z >> /dev/null 2>&1
# This Script will start|stop|restart CumulusMX as a detached Screen session.
#
# Type ./cumulusmx.sh -h for more information and available parameters
#
# Use this Script at your own Risc. You should always have a Backup of your files.

VERSION='2.5.5.0 (2017-09-11)'
INSTPATH="/CumulusMX"  # Example "/home/pi/CumulusMX" without ending /

# Please change the INSTPATH settings above if the CumulusMX folder is other then /home/pi/CumulusMX. (/media/usbstick/CumulusMX) All other settings need to be done in file cumulusmxsh.conf

#-----------> No need to edit anything below this line <--------------

export TERM=xterm    # To avoid error messages when starting at reboot
### Find if -h (HELP) Parameter is set to get HELP Screen of Cumulus
 if [ "$1" = "-h" ] || [ "$1" = "--h" ] ; then
           echo -e "\nCumulusMX $VERSION Start|Stop|Restart Script\nFind more information at http://sandaysoft.com/forum/viewtopic.php?f=27&t=13767\n"
           echo -e "Usage: sudo ./cumulusmx [OPTION]...Example: sudo ./cumulusmx.sh -p 9999\n\n"
           echo "  -h                 HELP, This screen"
           echo "  -s                 CumulusMX Status"
           echo "  -r                 Restart CumulusMX"
           echo "  -q                 Quit CumulusMX"
           echo "  -p [1-65535]       Start CumulusMX on TCP Port (Range: 1-65535) or edit the PORT value in the head of the script"
           echo "  -d                 Resume Screened $SERVICE Session"
           echo "  -b [-z,-t,-d,-c]   Backup CumulusMX with zip,tar.gz,dd or Cloud-WebDAV (sudo ./cumulusmx.sh -b [-t,-z,-d,-c] )"
           echo "  -n                 Cumulus Now - Current WeatherStation values"
           echo "  -l                 Logfile Viewer (Menu based)"
           echo "  -u                 Update Cumulus from an official CumulusMXDist3xxx.zip (You will be guided through this Process)"
           echo "  -m                 Create zip file with the latest MXdiags log"
           echo "  -c                 Will guide you through a System check: Network Settings/FTP Settings/CumulusMX Basic config check"
           echo "  -system [-r,-q]    Option -system will open a reboot/shutdown menu. Additional Options [-r, -q] (./cumulusmx.sh -system -r, -q)"
           echo "  -w                 Watchdog Option - when script will be called by cron in a loop instead of init.d script"
           echo -e "  -v                 Print Version\n\n"
           exit
 fi

### Color Settings
WARNCOLOR="\033[01;33m"
ALARMCOLOR="\033[01;31m"
VIOLET="\033[01;35m"
GREEN="\033[01;32m"
RESTORE="\033[0m"

# check if variable Instpath is set correctly
  if [[ ! -d $INSTPATH  ]]; then
      clear
      echo -e "\n\n"$ALARMCOLOR"The path to your CumulusMX folder is not set correctly in file cumulusmx.sh line 16, because I can not find CumulusMX at this path: "$GREEN"$INSTPATH.\n"$WARNCOLOR"Please use an editor and insert the correct path to your CumulusMX Installation folder above in line 16\n"$RESTORE"\n"
      exit
  fi

echo -e "\n     Collecting Information from your system, please wait.......\n"
### find the  Configuration File (cumulusmxsh.conf, Pid of mono, System Uptime, Cumulus runtime and IP Address
export PATH=$PATH:/sbin

## Check for configuration file
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
  if [ -f $INSTPATH/cumulusmxsh.conf ]; then
      CONFIG="$INSTPATH/cumulusmxsh.conf"
    elif [ -f $DIR/cumulusmxsh.conf ]; then
      CONFIG="$DIR/cumulusmxsh.conf"
    elif [ -f /etc/cumulusmxsh.conf ]; then
      CONFIG="/etc/cumulusmxsh.conf"
    else
      echo -e "\n\n"$ALARMCOLOR"Attention:"$WARNCOLOR" Configuration File: "$RESTORE"cumulusmxsh.conf"$WARNCOLOR" not found. Neither in /etc/cumulusmxsh.conf nor $INSTPATH/cumulusmxsh.conf"
      echo -e "Please make sure, that the Configuration File exist in one of these two locations"$RESTORE"\n\n"
    exit
  fi
source $CONFIG
## END - Check for configuration file
  if [ ! "$1" = "-w" ]; then
  echo "$(date "+%F %T") - CumulusMX $VERSION Script is being called with some Parameter" >> $LOGPATH 2>&1
  fi

###  Adding new Parameters to Conf File
# Parameter Installation Path

   if ! grep -Fq "Since Version 2.5.4.0" $CONFIG ; then
      sed -i '1 i\# Since Version 2.5.4.0 it is mandatory to configure the installation path of CumulusMX in line 16 of the cumulusmx.sh script\n# In case CumulusMX is installed in /home/pi/CumulusMX nothing needs to be done, because this is the default value.\n# In case your installation directory is other then the above, please change the variable: INSTPATH="" in cumulusmx.sh line 16\n'  $CONFIG
   fi

# Parameter Logpath

   if ! grep -Fq "LOGPATH=" $CONFIG ; then
      sed -i '/SERVICE=/a\\n# Path to cumulusmxsh.log file \nLOGPATH=$INSTPATH/cumulusmxsh.log' $CONFIG
   fi

# Parameter NETWORKFAILCOUNT
   if  ! grep -Fq "NETWORKFAILCOUNT=" $CONFIG ; then
         sed  -i '$a \\n# If cumulusmx.sh is being auto-started at reboot, how long should be waited until Internet\\Network Connection can be established \n# Default: NETWORKFAILCOUNT=5 (minutes) 0 = (wait forever) \nNETWORKFAILCOUNT=5' $CONFIG
   fi

# Parameter NETWORKFAILOVER
   if  ! grep -Fq "NETWORKFAILOVER=" $CONFIG ; then
         sed  -i '$a \\n# If Internet/Network is not up after NETWORKFAILCOUNT, should CumulusMX being started or not? 0=Quit Script, 1=Continue Script (Default = 1) \nNETWORKFAILOVER=1' $CONFIG
   fi
# Parameter MXLANGUAGE
   if  ! grep -Fq "MXLANGUAGE=" $CONFIG ; then
         sed  -i '$a \\n# Normally CumulusMX language settings are equal System language. In case you want to use a different Language for system and CumulusMX \n# use this parameter to start CumulusMX with different language. Refer to http://sandaysoft.com/forum/viewtopic.php?f=27&t=12908 - Important note about locales \n# Example: MXLANGUAGE="-lang de-DE" (Default = "")\nMXLANGUAGE=""' $CONFIG
   fi

# Parameter Logfile size
   if  ! grep -Fq "LOGSIZE=" $CONFIG ; then
   sed  -i '$a \\n# Size of Logfile cumulusmxsh.log in KB (Default = 10000) \nLOGSIZE=10000' $CONFIG
   fi

# Parameter Cloud Backup
  if ! grep -Fq "CLOUDPROTO=" $CONFIG ; then
  sed -i '/LOOP=/a\\n#<----- Cloud / WebDav Backup -----> \n\n# CLOUDPROTO https or http for WebDav Access \nCLOUDPROTO=https\n# URL of the WEBDAV Server (Example: "webdav.mycloudspace.com")\nCLOUDSERVER=""\n# Cloud Upload timeout in Seconds. Time upload can take until it will timeout. Default: 1500 Seconds. Example: CLOUDUPTIMEOUT=1500\nCLOUDUPTIMEOUT=1500 \
# Path on the Webdav server where Backups are stored (Example: "/Backup/Cumulus"\nCLOUDPATH="" \
# Username and Password for WeBDav Access - In case username or password contains an @ sign, please use "%40" instead (user@gmail.com ---> user%40gmail.com)\nCLOUDUSER=""\nCLOUDPASS=""\n\n#<---- End Cloud Backup ---->#' $CONFIG
  echo -e "$(date "+%F %T") - "$WARNCOLOR"Updating Config file with new Parameter(s). Please restart Script and check for new Parameters in cumulusmxsh.conf\n"$RESTORE"" | tee -a $LOGPATH
  exit
  fi


### Check permissions on CumulusMX Folder, when not called as root ####
WHOAMI=$(whoami)
OWNER=$(find $INSTPATH/ -type f -printf "%u \n" |sort |uniq)
PIDOWNER=$(stat -c %U /tmp/$SERVICE.pid 2> /dev/null)
 if [ "$(whoami)" != "root" ] 2> /dev/null ; then
     if [ -f /tmp/$SERVICE.pid ] ;then
      if [ "$PIDOWNER" != "$WHOAMI" ]; then
        clear
        echo -e ""$WARNCOLOR"\n     It seem that $SERVICE was not properly stopped last time, or initially started as"$RESTORE" $PIDOWNER (sudo)"
        echo -e ""$WARNCOLOR"     To ensure, that $SERVICE was started and managed by the same user account, don't start it at user:"$RESTORE" $WHOAMI"$WARNCOLOR", but as"$RESTORE" $PIDOWNER (with sudo)"
        echo -e ""$WARNCOLOR"     If you want to manage $SERVICE as user "$RESTORE"$WHOAMI"$WARNCOLOR", stop $SERVICE (sudo ./cumulusmx.sh -q) and make sure that /tmp/$SERVICE.pid file is not existing anymore (sudo rm /tmp/$SERVICE.pid)"$RESTORE"\n"
        ls -al /tmp/$SERVICE.pid
        echo -e ""$WARNCOLOR"     A mixed usage of CumulusMX is really not recommended. Always use the same useraccount to run and manage CumulusMX. Use always sudo or always without sudo (as user pi)"
        echo -e "\n"
        exit
      fi
     fi
      if (( $(grep -c . <<<"$OWNER") > 1 )); then
        echo -e "\n     "$WARNCOLOR"You are running CumulusMX not as root (sudo) but as user:"$ALARMCOLOR" $WHOAMI"$WARNCOLOR" - but I found files in "$INSTPATH" which are having different owners"$RESTORE""
        echo -e "$OWNER"
        echo -e "     "$WARNCOLOR"This probably happened because this Script was previously started with sudo and now without sudo."
        echo -e "     This might cause trouble, because of <Permission Denied> problems to read and write files."
        echo -e "     Please fix this problem by using this command: "$VIOLET"sudo chown -R "$WHOAMI":"$WHOAMI" "$INSTPATH""$RESTORE"\n     This will change the owner of all files in "$INSTPATH" to owner: "$WHOAMI"\n"
        echo -e "     If you want to check the files and owners by yourself, please use this command:"
        echo "     sudo find "$INSTPATH" -type f -printf '%u %p\\n' |sort |more"
        exit
      fi
fi



MONOPID=$(pgrep mono && echo)
UPTIME=$(uptime | sed s/^.*up// | awk -F, '{ if ( $3 ~ /user/ ) { print $1 $2 } else { print $1 }}' | sed -e 's/:/\ hours\ /' -e 's/ min//' -e 's/$/\ minutes/' | sed 's/^ *//')
#OS 8 - Jessie PRETTYUPTIME=$(uptime -p |cut -d " " -f2-)
#OS 7 - Wheezy PRETTYUPTIME=$(uptime | sed 's/^.* up \+\(.\+\), \+[0-9] user.*$/\1/')
RUNTIME=$(find /tmp/$SERVICE.pid -maxdepth 0 -printf "%TY-%Tm-%Td %TH:%TM\n")
INTERFACE=$(/sbin/route -n | awk '($1 == "0.0.0.0") { print $NF ; exit }')
IPADDRESS=$(hostname -I)
NETMASK=$(ifconfig | grep -w inet |grep -v 127.0.0.1| awk '{print $4}' | cut -d ":" -f 2)
UPDATEPATH=$(dirname $INSTPATH)


### Get Script Version and CumulusNow Version

MXVERSIONONLINE=$(curl -s http://sandaysoft.com/forum/ -o /tmp/version.txt | grep -i "Latest Cumulus MX release" /tmp/version.txt | sed 's/^.*v3.0.0/>v3.0.0/' |cut -c2-18)

VERSIONONLINE=$(wget -q -O- http://bit.ly/1H0ZVUV |grep "^VERSION" |cut -d "=" -f2)
NOWVERSIONONLINE=$(wget -q -O- http://bit.ly/1H0ZVUV |grep "CumulusNow" |head -n1| cut -d "=" -f2)
  if [ -f $INSTPATH/cumulusnow.sh ] ;then
     NOWVERSION=$(grep Version $INSTPATH/cumulusnow.sh |cut -d " " -f2)
  else
     NOWVERSION="Not Installed yet.Please check option <-n>"
  fi


### Get CumulusMX Version
MXVERSION=$(find $INSTPATH/MXdiags/*.txt -type f -printf '%T@ %p\n' | sort -n | tail -1 | cut -f2- -d" " |xargs grep "Cumulus MX v" |cut -c25- )
 if [ "$1" = "-v" ]; then
           echo -e "\nCumulusMX Start|Stop|Restart Script - Version: $VERSION\nCumulusNow Version: $NOWVERSION\nCumulusMX Version: $MXVERSION\n"
           exit
 fi
clear
### Find out if CumuluxMX and Mono and Screen is installed - if this is the right Cumputer

 if [ ! -d "$INSTPATH" ];then
    echo "Directory $IPATH file does not exist or Variable <IPATH> is not properly set, or you are connected to wrong computer. I will quit now"
    exit
    else
    if [ ! -f "$INSTPATH/CumulusMX.exe" ];then
    echo "Directory $IPATH exist, but I can not find CumulusMX.exe - I will quit Now"
    exit
    fi
 fi

### Check if Mono is installed
 which mono >/dev/null 2>&1
  if [ $? -ne 0 ]; then
   echo -e ""$ALARMCOLOR"Mono is not found in path but it is mandatory, please install mono. Refer to <http://sandaysoft.com/forum/viewtopic.php?f=27&t=$\n"
   exit
  fi

### Check if Screen is installed
 if [ ! -f /usr/bin/screen ]; then
    echo -e "Sorry, <screen> needs to be installed. Please install with  <sudo apt-get install screen> or continue with installing automatically"
    echo -e "Screen is a full-screen window manager that multiplexes a physical terminal between several processes (typically interactive shells)"
    read -r -p "Do you want to install screen now? ? [Y/n]" response
    response=${response,,} # tolower
       if [[ $response =~ ^(yes|y| ) ]]; then
          apt-get install screen
          echo -e "\nScreen successfully being installed - Please repeat the command again\n"
          exit
       else
          exit
        fi
 fi

### Check remaining Diskspace
    DISKALARM="0"
    CURRENT=$(df $INSTPATH | grep / | awk '{ print $5}' | sed 's/%//g')
 if [ "$CURRENT" -ge "$DISKTHRESALARM" ] ; then
     echo  -e ""$ALARMCOLOR"Disk Space Alert - Your root partition remaining free space is critically low. Used: $CURRENT%"
     DISKALARM="2"
   else
    if [ "$CURRENT" -ge "$DISKTHRESWARN" ] ; then
     echo -e ""$WARNCOLOR"Warning: Diskusage is at $CURRENT% $RESTORE"
     DISKALARM="1"
    fi
 fi

### Check if cumulus is running based on PID
 if [ -f /tmp/CumulusMX.pid ]
  then
    RUNNING='running'
    RUNCOLOR="\033[01;32m"
  else
    RUNNING='not running'
    RUNCOLOR="\033[01;31m"
 fi

###### Ceck if TCP Port configured above is being used
  CHECKPORT=$(nc -z $IPADDRESS $PORT;echo $?)
   if [ $CHECKPORT == 0 ]; then
    REALPORT=""
   else
    REALPORT=""$ALARMCOLOR"not"$RESTORE""
    REALPORT2=""$WARNCOLOR"\nMaybe CumulusMX has not finnished to start yet or running on a different TCP Port then $PORT.\nPlease wait additional 30 seconds and try again, If it still fail, restart CumulusMX to clearly start on TCP Port $PORT"$RESTORE" <(sudo) ./cumulusmx.sh -r>"
   fi


###### Check if Logfile size is larger then configured
    if [[ $(find "$LOGPATH" -type f -size +"$LOGSIZE"c ) ]]; then
      rm "$LOGPATH"
      echo "$(date "+%F %T") - CumulusMX Logfile reached $LOGSIZE. Truncating old Logfile, creating a new Logfile" >> $LOGPATH 2>&1
    fi
###### Check If  Script is called with parameters ######

### Check if -system option - show System  Menu or check if -system [-r -q]

 if [ "$1" = "-system" ]; then
        echo -e ""$WARNCOLOR"This menu will safe end $SERVICE and shutdown or reboot your System"
        echo -e "Option"$RESTORE" -system -r"$WARNCOLOR" will reboot imidiately | option "$RESTORE" -system -q "$WARNCOLOR"will shutdown immidiately"$RESTORE""
        echo -e "Example for cron: <0 1 0 0 6 /usr/bin/sudo /home/pi/cumulusmx.sh -system -r> will reboot Raspberry Pi Saturday morning at 1 am\n"
        while getopts ':srq:' OPTION ; do
             case "$OPTION" in
              r) echo -e "\n"$ALARMCOLOR"You choosed to reboot the system"$RESTORE"\n"
                 read -p  "Press any key to continue...CTRL+C to break (or wait 10 seconds to automatically reboot the system)" -n 1 -t 10
                 screen -X -S $SERVICE  stuff "^C"
                 sleep 5
                 kill -5 $MONOPID
                 rm /tmp/$SERVICE.pid
                 echo -e ""$WARNCOLOR"SERVICE "$SERVICE" is being stopped"$RESTORE" - Proceeding with reboot\n"
                 shutdown -r now
                 echo "reboot";;
              q) echo -e "\n"$ALARMCOLOR"You choosed to shut down the system"$RESTORE"\n"
                 read -p  "Press any key to continue...CTRL+C to break (or wait 10 seconds to automatically shutdown the system)" -n 1 -t 10
                 screen -X -S $SERVICE  stuff "^C"
                 sleep 5
                 kill -5 $MONOPID
                 rm /tmp/$SERVICE.pid
                 echo -e ""$WARNCOLOR"SERVICE "$SERVICE" is being stopped"$RESTORE" - Proceeding with shutdown\n"
                 shutdown -h now
                 echo "shutdown"
             # *) echo "Unknown parameter $1 $2 - Please try -r or -q or use ./cumulusmx -h for help"
             #    exit
            esac
       done
 fi

  if [ "$1" = "-system" ]; then
    PS3="System Menue - What do you want to do now? "
    select foo in 'System Reboot' \
                'System Shutdown' \
                'Quit'; do
    case "$REPLY" in
     1) echo -e "\n"$ALARMCOLOR"You choosed to reboot the system"$RESTORE"\n"
        read -p  "Press any key to continue...CTRL+C to break (or wait 10 seconds to automatically reboot the system)" -n 1 -t 10
        screen -X -S $SERVICE  stuff "^C"
        sleep 5
        kill -5 $MONOPID
        rm /tmp/$SERVICE.pid
        echo -e ""$WARNCOLOR"SERVICE "$SERVICE" is being stopped"$RESTORE" - Proceeding with reboot\n"
        shutdown -r now
        exit;;
     2) echo -e "\n"$ALARMCOLOR"You choosed to shut down the system"$RESTORE"\n"
        read -p  "Press any key to continue...CTRL+C to break (or wait 10 seconds to automatically shutdown the system)" -n 1 -t 10
        screen -X -S $SERVICE  stuff "^C"
        sleep 5
        kill -5 $MONOPID
        rm /tmp/$SERVICE.pid
        echo -e ""$WARNCOLOR"SERVICE "$SERVICE" is being stopped"$RESTORE" - Proceeding with shutdown\n"
        shuttdown -h now
        exit;;
     3) exit
    esac
   done
  fi

### Check if -n Cumulus Now
 if [ "$1" = "-n" ]; then
    if [ -f $INSTPATH/cumulusnow.sh ] ;then
    echo -e "$(date "+%F %T") - CumulusNow - External program Cumulusnow is bein started" >> $LOGPATH
    exec ""$INSTPATH"/cumulusnow.sh"
   else
    echo -e "\n"$WARNCOLOR"CumulusNow"$RESTORE" is "$ALARMCOLOR"not"$RESTORE" installed on your system or can not be found in the installation directory of "$INSTPATH"\n"
    echo -e ""$WARNCOLOR"CumulusNow"$RESTORE" is a small script which can display your current Weatherstation values like temperature, windspeed,humidity and more directly within this SSH Session."
    echo -e "You can find more information and download it in this Forum Post: http://sandaysoft.com/forum/viewtopic.php?f=27&t=13767&start=90,"
    echo -e "or you can download this Script directly from here.\n"
    read -r -p "Do you want to download and install the script directly from here now? ? [Y/n]" response
     response=${response,,} # tolower
         if [[ $response =~ ^(yes|y| ) ]]; then
            curl http://jankreutzer.de/sites/cumulusmx/cumulusnow.zip --output /tmp/cumulusnow.zip
            unzip /tmp/cumulusnow.zip -d $INSTPATH/
            chmod +x $INSTPATH/cumulusnow.sh
            echo -e "\n Cumulusnow was successfully downloded and extracted - Please repeat the command again\n" | tee -a $LOGPATH
            exit
         fi
         echo -e "\nOkay, your decision was NO. You want to download it manually."
         echo -e "Step 1: Point your Webbrowser to this URL: http://sandaysoft.com/forum/viewtopic.php?f=27&t=13767&start=90 and download the ZIP"
         echo -e "Step 2: Use WINSCP to copy the ZIP to your RaspberryPi "$INSTPATH/" folder"
         echo -e "Step 3: Unzip the file into "$INSTPATH"/ folder"
         echo -e "Step 4: Login as root an make the script executable: "$WARNCOLOR"sudo chmod +x "$INSTPATH"/cumulusnow.sh"$RESTORE""
         echo -e "Call cumulusmx.sh -n again"
    fi
  exit
 fi

### Check if -c Check Network Settings
 DEFAULTGW=$(/sbin/ip route | awk '/default/ { print $3 }')
      if [ "$1" = "-c" ]; then
        echo -e "\nThis Test will do some basic Cumulus related tests like Network Settings, FTP Settings System Settings. This test might fail on other devices then Raspberry Pi"
        echo -e "If all results are green, everything is fine - Are you ready to continue?\n\n"
        read -p "Press [Enter] key to start the test..."
        clear
        echo -e "\n"$VIOLET"  Step 1: Your Network Settings"$RESTORE""
        echo -e "\n  a) If you don't see an IP Address and Netmask in the next line, something is not correct in your network settings"
        echo -e "     --> You are using Interface "$GREEN"$INTERFACE"$RESTORE". I identified your internal IP Address as: "$GREEN"$IPADDRESS"$RESTORE" Netmask as "$GREEN"$NETMASK"$RESTORE" and default gateway is "$GREEN"$DEFAULTGW"$RESTORE""
        echo -e "\n  b) You should have a fixed IP Address instead of using DHCP to avoid sudden IP Address changes"
       FIXEDIP=$(cat /etc/network/interfaces |grep "iface $INTERFACE inet dhcp")
       if [ "$FIXEDIP" == "iface $INTERFACE inet dhcp" ]; then
        DHCP="     --> "$WARNCOLOR"You are using DHCP and should consider to change to a fixed IP Address - http://bfy.tw/LUz"$RESTORE""
       else
        DHCP="     --> You are using a "$GREEN"fixed IP address which is good"$RESTORE""
       fi
      echo -e "$DHCP"
      echo -e "\n  c) Your DNS Server should be properly configured and it should be reachable from this device"
     #Check DNS Server
       DNSSERVER=$(cat /etc/resolv.conf |grep -i nameserver|head -n1|cut -d ' ' -f2)
       ping $DNSSERVER -c 1 > /dev/null 2>&1
         if [ $? = 0 ]; then
           DNSPING=""$GREEN"is reachable"$RESTORE""
         else
           DNSPING=""$ALARMCOLOR"is not reachable"$RESTORE""
         fi
     #Check DefaultGW
       ping $DEFAULTGW -c 1 > /dev/null 2>&1
         if [ $? = 0 ]; then
           DEFAULTGWPING=""$GREEN"is reachable"$RESTORE""
         else
           DEFAULTGWPING=""$ALARMCOLOR"is not reachable"$RESTORE""
         fi
     #Check if Internet is reachable
        ping www.google.com -c 1 > /dev/null 2>&1
         if [ $? = 0 ]; then
           GOOGLEPING=""$GREEN"is reachable"$RESTORE""
         else
           GOOGLEPING=""$ALARMCOLOR"is not reachable"$RESTORE""
         fi

     echo -e "     --> Your DNS Server is having the IP Address: "$GREEN"$DNSSERVER"$RESTORE" and it $DNSPING"
     echo -e "     --> Your Default Gateway is having the IP Address: "$GREEN"$DEFAULTGW"$RESTORE" and it is $DEFAULTGWPING"
     echo -e "\n  d) Of course you should have an external IP Address to be able to reach other computers in the internet"
      EXIP=$(curl -s  http://ipinfo.io/ip)
      EXHOST=$(curl -s  http://ipinfo.io/hostname)
      COUNTRY=$(curl -s http://ipinfo.io/country)
      echo -e "     --> Your external IP Address is "$GREEN"$EXIP"$RESTORE" and your internet hostname is "$GREEN"$EXHOST"$RESTORE" located in "$GREEN"$COUNTRY"$RESTORE""
      echo -e "     --> Your Device: "$GREEN"$IPADDRESS"$RESTORE" ----> DefaultGateway: "$GREEN"$DEFAULTGW"$RESTORE" ("$DEFAULTGWPING") ----> Internet (Google): $GOOGLEPING\n\n\n"
      read -p "Press [Enter] key to start the next test...[FTP Settings] - (Attention, on the next page, your FTP Password will be displayed)"
      clear
      ### Checking FTP Settings
      echo -e "\n\n"$VIOLET"  Step 2: Checking the FTP Settings of CumulusMX now"$RESTORE"\n"
       FTPHOST=$(grep -A 5 "FTP site" $INSTPATH/Cumulus.ini | grep Host | cut -d = -f 2)
       FTPPORT=$(grep -A 5 "FTP site" $INSTPATH/Cumulus.ini | grep Port | cut -d = -f 2)
       FTPUSER=$(grep -A 5 "FTP site" $INSTPATH/Cumulus.ini | grep Username | cut -d = -f 2)
       FTPPASS=$(grep -A 5 "FTP site" $INSTPATH/Cumulus.ini | grep Password | cut -d = -f 2)
       FTPDIR=$(grep -A 5 "FTP site" $INSTPATH/Cumulus.ini | grep Directory | cut -d = -f 2)
       echo -e "    I found the following configured FTP settings\n"
       echo -e "     --> FTP Server you upload your html pages is: "$GREEN"$FTPHOST"$RESTORE""
       echo -e "     --> The TCP PORT used on this FTP Server is TCP Port: "$GREEN"$FTPPORT"$RESTORE""
       echo -e "     --> You configured the following Username to upload the files: "$GREEN"$FTPUSER"$RESTORE""
       echo -e "     --> The Password you are using is: "$GREEN"$FTPPASS"$RESTORE""
       echo -e "     --> The directory you used to upload the files is: "$GREEN"$FTPDIR"$RESTORE""
       echo -e "\n    Now I will check the FTP connectivity and if it is allowed to upload files to the configured FTP directory "$FTPHOST"$FTPDIR \n"
       if [ -z "$FTPHOST" ]; then
           echo -e "\n\n"$WARNCOLOR"You have not configured the FTP Server Settings yet.  Please ignore all following errors on this page and proceed wit the next test "$GREEN"[System Settings]"$RESTORE""
       fi
       echo -e "\n  e) The first Test will check the connection to your FTP Server and if the directory ($FTPDIR) is available and count the files in the directory\n     You should see a Number larger 0 as a result"
       CONNECT=$(curl  -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS" |wc -l |xargs)
          if [ $CONNECT == 0 ]; then
       echo -e "\n\n     "$ALARMCOLOR" Something seem not to be working with the connection to your FTP Server.\n      It makes no sense to proceed with the Test.\n      Please use a FTP Program with a graphical Interface to test your Settings again\n      I am sorry the test will be stopped here"$RESTORE$""
       echo -e "\n\n     Please see the error in detail\n"
       curl -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS" |wc -l
          fi
       curl  -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS" |wc -l |xargs echo -e "    -->"$GREEN" Files in this directory:"$RESTORE""
       echo -e "\n  f) The next test will upload a dummy file into this directory, to check if the directory permission to copy files to\n     Server: "$GREEN"$FTPHOST"$RESTORE" - Folder: "$GREEN" $FTPDIR "$RESTORE" is correctly set"
       echo "    --> The Test upload to your FTP Server was successful, if you could read this line" >/tmp/cumulusmx_upload_test.txt
       curl -s -m 10 -T /tmp/cumulusmx_upload_test.txt ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS"
       echo -e ""$GREEN" "
       curl  -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/cumulusmx_upload_test.txt --user "$FTPUSER":"$FTPPASS"  | cat
       echo -e ""$RESTORE" "
       echo -e "  g) The Number of files should be increase by 1 now compared to step e)"
       curl -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS" |wc -l |xargs echo -e "    -->"$GREEN" Files in this directory:"$RESTORE""
       echo -e "       (You can check your FTP Server, if a file "$FTPDIR"/cumulusmx_upload_test.txt exist\n       or point your WebBrowser to: http://"$FTPHOST""$FTPDIR"/cumulusmx_upload_test.txt) now, before you proceed with the test"
       echo -e "\n  h) The uploaded dummy file will now be deleted from your FTP Server.\n"
       read -p "Press [Enter] key to continue..."
       echo -e "\n     The Number of files should now decrease by 1 compared to step g) "
       curl -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ -X 'DELE cumulusmx_upload_test.txt' --user "$FTPUSER":"$FTPPASS"
       curl -s -m 10 ftp://"$FTPHOST":"$FTPPORT""$FTPDIR"/ --user "$FTPUSER":"$FTPPASS" |wc -l |xargs echo -e "    -->"$GREEN" Files in this directory:"$RESTORE""
       echo -e "\n\n"
       read -p "Press [Enter] key to start the next test...[Cloud Backup - WebDAV Test]"
       clear
       ###  Check Cloud Backup Settings

       echo -e "\n\n"$VIOLET"  Step 3: Checking your Cloud Backup (WebDAV Settings if enabled in cumulusmxsh.conf)"$RESTORE"\n"
       if [  "$CLOUDSERVER" ] ; then
          echo -e "    I found the following configured Cloud Backup settings\n"
          echo -e "     --> Cloud Backup - WebDav Protocol is: "$GREEN"$CLOUDPROTO"$RESTORE""
          echo -e "     --> Cloud Backup - WebDav Server is: "$GREEN"$CLOUDSERVER"$RESTORE""
          echo -e "     --> You configured the following Username to backup to cloud: "$GREEN"$CLOUDUSER"$RESTORE""
          echo -e "     --> The Password you are using for Cloud Backup is: "$GREEN"$CLOUDPASS"$RESTORE""
          echo -e "     --> The directory you used to upload the Backup to Cloud is: "$GREEN"$CLOUDPATH"$RESTORE""
          echo -e "     --> The timeout for the upload in seconds is: "$GREEN"$CLOUDUPTIMEOUT"$RESTORE" Seconds\n"
               if [[ $CLOUDUSER == *[@]* || $CLOUDPASS == *[@]* ]] ; then
                    echo -e "\n"$ALARMCOLOR"Found @ character in WebDAV username or password"$RESTORE" - "$WARNCOLOR"In case username or password contains an @ sign, please replace "$ALARMCOLOR"@"$WARNCOLOR" with $GREEN"%40""$WARNCOLOR"!!!"$RESTORE""
                    echo -e ""$ALARMCOLOR"Fix it, otherwise Cloud Backup Test will fail!!!"$RESTORE"\n\n"
                    echo -e "\nExiting Cloud Backup and system settings checks now"
                    exit
               fi
          echo -e "     The next test will create and upload a 10 MB dummy file into this Cloud Backup directory, to check if the upload to\n     Server: "$GREEN"$CLOUDSERVER"$RESTORE" - Folder: "$GREEN"$CLOUDPATH"$RESTORE" is working correctly\n"
          read -p "Press [Enter] key to start the upload test..."
          dd if=/dev/zero of=/tmp/10MB bs=1024 count=10240
          curl -S -v -m 180 -T /tmp/10MB $CLOUDPROTO://$CLOUDUSER:$CLOUDPASS@$CLOUDSERVER/$CLOUDPATH/ > /dev/null
          #curl -S -m $CLOUDUPTIMEOUT -T /tmp/"$CLOUDDATE"_"$SERVICE".zip $CLOUDPROTO://$CLOUDUSER:$CLOUDPASS@$CLOUDSERVER/$CLOUDPATH/ > /dev/null | tee -a $LOGPATH
          echo -e "\n\n"$GREEN"You can check on your Cloud Space if the file "$CLOUDPATH"/10MB exists"$RESTORE""
          echo -e "$CLOUDPROTO://$CLOUDUSER:$CLOUDPASS@$CLOUDSERVER/$CLOUDPATH/10MB"
          read -p "Press [Enter] key to delete the file..."
          curl -X DELETE "$CLOUDPROTO://$CLOUDUSER:$CLOUDPASS@$CLOUDSERVER/$CLOUDPATH/10MB"
          rm /tmp/10MB
          echo -e ""$GREEN"Cloud upload is working, test file on cloud space deletet"$RESTORE"\n"
       else
         echo -e ""$GREEN"Cloud Backup Settings are not configured, skipping to next test"$RESTORE"\n"
       fi
       read -p "Press [Enter] key to start the next test...[System Test]"
       clear
       ### End  Check Cloud Backup Settings
       ### Checking system Settings
       echo -e "\n\n"$VIOLET"  Step 4: Checking your System Settings and Cumulus Settings"$RESTORE"\n"
        OS=$(cat /etc/*release |grep -i "^NAME=" |cut -d = -f 2)
        OSVERSION=$(cat /etc/*release |grep -i "^VERSION=" |cut -d= -f 2 |xargs $FLAVOUR | tr '[:lower:]' '[:upper:]')
        FLAVOUR=$(cat /etc/*release |grep -i "ID_LIKE=" |cut -d= -f 2 |xargs $FLAVOUR | tr '[:lower:]' '[:upper:]')
        LOAD=$(uptime | awk '{ print $10 }' | cut -c1)
         if [ $LOAD -lt 1 ]; then
            LOADALARM="Current CPU Load is"$GREEN" $LOAD.x which is fine"$RESTORE""
         else
            LOADALARM="Current CPU Load is"$ALARMCOLOR" $LOAD which is high. Check with command <top> which process is causing such high load"$RESTORE""
         fi

        FREE=$(df -m / | tail -1 | awk '{ print $4 }')
        CURRENT=$(df / | grep / | awk '{ print $5}' | sed 's/%//g')
               DISKALARM=""$GREEN"$CURRENT% disk space used so far which is enough to run CumulusMX"$RESTORE""
             if [ $CURRENT -ge 90  ]; then
               DISKALARM=""$ALARMCOLOR"Disk Space Alert - Your root partition remaining free space is critically low. Used: "$CURRENT%""
              else
              if [ $CURRENT -ge 80 ]; then
              DISKALARM=""$WARNCOLOR"Warning: Diskusage is at "$CURRENT%" "$RESTORE""
               fi
             fi
        TOTAL=$(df -m / | tail -1 | awk '{ print $2 }')
        MODEL=$(uname -m |head -c-2)
        if  [ $MODEL == armv7 ]; then
          RASP="Raspberry Pi 2 Model B"
        else
          RASP="Raspberry Pi A(+) or B(+)"
        fi
        MONOREV=$(mono -V |head -1|cut -c 27)
          if [ $MONOREV == 4 ]; then
           MONOSTAT=""$GREEN"Your installed Mono Version is the best for your $RASP"$RESTORE""
          else
           MONOSTAT=""$WARNCOLOR"You are running a $RASP so you should use the most Current Version of Mono which is Version 4.x.x - You are using Version 3.x.x"$RESTORE" --> http://sandaysoft.com/forum/viewtopic.php?f=27&t=14222"
          fi
        PROCESSES=$(ps aux | wc -l)
        TIME=$(date)
        CPUTEMPFULL=$(vcgencmd measure_temp | cut -d= -f2)
        CPUTEMP=$(vcgencmd measure_temp | cut -d= -f2 |cut -d. -f1)
        OSLANG=$(locale | grep LANG | cut -d= -f2)
        MXLANG=$(ls -t /$INSTPATH/MXdiags/*.txt | head -1 |xargs grep "Current culture" |cut -d " " -f5)
        STATION=$(ls -t /$INSTPATH/MXdiags/*.txt | head -1 |xargs grep "Station type" |cut -d " " -f5-)
        MONO=$(mono -V |head -1)
        COMPORT=$(grep "ComportName" /$INSTPATH/Cumulus.ini |cut -d "=" -f2)
          if [ ! -b $COMPORT ]; then
           COMPORTSTAT=""$GREEN"and this Port $COMPORT exist,which is fine"$RESTORE""; else
           COMPORTSTAT=""$ALARMCOLOR"but $COMPORT Device does not exist in /dev/ directory - Please check your Hardware"$RESTORE""; fi
       ###  Checking if  /dev/ttyUSB0 can be found as file , comparing to the Cumulus.ini settings
          if [ ! -f /dev/ttyUSB0 ]; then
             COMDEV=$"/dev/ttyUSB0"
          fi
          if [ ! "$COMDEV" == "$COMPORT" ];then
            COMDEVSTAT=""$ALARMCOLOR"Something seem to be wrong! \n I can find "$WARNCOLOR"/dev/ttyUSB0"$ALARMCOLOR" as a valid device driver, but you have not configured it in your Cumulus.ini. You configred "$WARNCOLOR" "$COMPORT""$ALARMCOLOR".\n        Usually on a Linux System, serial ports are named "$WARNCOLOR"/dev/ttyUSBx"$ALARMCOLOR" and not COMx as on windows.\n Goto http://$IPADDRESS:$PORT/stationsettings.html -> <Serial port name> and insert "$GREEN"/dev/ttyUSB0"$ALARMCOLOR"  - Please correct this!!!"$RESTORE"\n"
            else
            COMDEVSTAT=""$GREEN"I can find device /dev/ttyUSB0 in your filesystem and it is also configured in your Cumulus.ini, which is good"$RESTORE""
         fi
        echo -e "     Operating System: "$GREEN""$OS" - "$FLAVOUR" - "$OSVERSION""$RESTORE""
        echo -e "     Raspberry Pi: "$GREEN"$RASP"$RESTORE""
        echo -e "     Systemload: $LOADALARM"
        echo -e "     Disk free: $FREE kb of total $TOTAL kb - $DISKALARM"
        echo -e "     Running Processes: $PROCESSES - should be below 120 Processes on such a small device as Raspberry Pi"
        echo -e "     Current time: "$GREEN"$TIME"$RESTORE" and Uptime of the System is: "$GREEN"$UPTIME"$RESTORE""
         if [ $CPUTEMP -lt 50 ]; then
            CPUTEMPALARM="Current CPU Temperature is "$GREEN"$CPUTEMPFULL which is fine"$RESTORE""
         else
            CPUTEMPALARM="Current CPU Temperature is "$ALARMCOLOR"$CPUTEMPFULL which is high. It should be less than 60 degree"$RESTORE""
         fi
        echo -e "     $CPUTEMPALARM"
        echo -e "     Installation Path of Cumulus is "$GREEN"$INSTPATH"$RESTORE" and the Dashboard is reachable "$GREEN"http://"$IPADDRESS":"$PORT""$RESTORE""
        echo -e "     System Language is: "$GREEN"$OSLANG"$RESTORE" and Language used in CumulusMX is: "$GREEN"$MXLANG"$RESTORE""
        echo -e "     Serial Device Status: "$COMDEVSTAT""
        echo -e "     Configured Weather Station is a "$GREEN"$STATION"$RESTORE" connected to $COMPORT $COMPORTSTAT"
        echo -e "     Version of CumuluxMX is: "$GREEN"$MXVERSION"$RESTORE" - You should check from time to time for new available Versions"
        echo -e "     Version of Mono is "$GREEN"$MONO"$RESTORE""
        echo -e "     "$MONOSTAT""
        echo -e "\n  i) Reading current Weather Station values"
        echo -e "     --> If you want to display the current Weatherstation values like Temp,Humidity,Rain,Windspeed, call this script with option -n"
        echo -e "\n  j) The following ini files are  having "," (Comma) instead of periods/full stops (.)\n     This often happens, when migrating from Cumulus 1.x  - http://sandaysoft.com/forum/viewtopic.php?f=27&t=12908.\n     If the list is empty, "$GREEN"your ini files are okay"$RESTORE""
        echo -e ""$ALARMCOLOR"   " && grep -l "," $INSTPATH/Cumulus.ini $INSTPATH/data/*.ini |  tr '\n' ' ' && echo -e ""$RESTORE"\n"
        echo -e "  k) The following devices are in Read Only mode which is not good. If list is empty, ""$GREEN""your device is okay""$RESTORE""" && echo -e ""$ALARMCOLOR""  && grep --color=always "\sro[\s,]" /proc/mounts | grep -v ':' | grep -v "tmpfs" && echo -e " "$RESTORE" \n\n"
        echo -e ""$RESTORE""
        read -p "Press [Enter] key to proceed with OS Update Check. This Process might take a while(""aptitude search"")"
        echo -e "\n  l) This Test will check if you have installed the most current updates for your Operating System "$GREEN""$OS" - "$FLAVOUR" - "$OSVERSION""$RESTORE".\n     This script will only count the available Updates for your OS which might take up to a minute\n      ....please be patient...."
         apt-get update >/dev/null 2>&1
         OSUPDATE=$(aptitude search '~U' | wc -l)
         if [ $OSUPDATE -gt 0 ]; then
           echo -e "\n     --> "$WARNCOLOR""$OSUPDATE" Updates are available at `date`\n         You should consider to update your System by using the command ""<sudo apt-get update>"" and ""<sudo apt-get upgrade>"""$RESTORE"\n"
          else
           echo -e "\n     --> "$GREEN""$OSUPDATE" Updates are available at `date`"$RESTORE"\n"
         fi
         echo -e "\n\n"$VIOLET"  End of System Check"$RESTORE"\n"
     exit
    fi

### Check if -m (Zip latest MXDiags)
    if [ "$1" = "-m" ]; then
     if [ ! -f /usr/bin/zip ]; then
     echo -e "Sorry, this function needs zip to be installed on your system but you haven't. Pease install zip with <sudo apt-get install zip>"
     read -r -p "Do you want to install zip now? ? [Y/n]" response
     response=${response,,} # tolower
         if [[ $response =~ ^(yes|y| ) ]]; then
            apt-get install zip
            echo -e "\nZip successfully being installed - Please repeat the command again\n"
            exit
         fi
      fi
         cd $INSTPATH/MXdiags/
         rm $INSTPATH/MXdiags/*.zip
         echo "zip the latest MXDiags Logfile for Upload to CumulusMX Forum."
         ls -t $INSTPATH/MXdiags/*.txt | head -1 |xargs zip -rj $(date +%F_%H%M)_MXDIAGS.zip ;
         echo "The  MXDiags zip file can be found in $INSTPATH/MXdiags/$(date +%F_%H%M)_MXDIAGS.zip"
         exit
    fi


#### Find if -r (Restart) Parameter is set to restart Cumulus
   if [ "$1" = "-r" ]; then
     printf "\n\033[1m\e[32mRestarting Cumulus now\n\n"     echo -e "\033[0m\n"
     screen -X -S "CumulusMX" stuff "^C"
     sleep 5 2>/dev/null
     kill -9 $MONOPID 2>/dev/null
     rm /tmp/$SERVICE.pid 2>/dev/null
     echo "$(date "+%F %T") - CumulusMX is being Stopped with Parameter -r (Restart)" >> $LOGPATH 2>&1
     cd $INSTPATH
     echo "$(date "+%F %T") - CumulusMX trying to start with these parameters $INSTPATH/CumulusMX.exe -port $PORT $MXLANGUAGE" >> $LOGPATH 2>&1
     screen -dmS $SERVICE -amds bash mono $INSTPATH/CumulusMX.exe -port $PORT $MXLANGUAGE
     echo $MONOPID > /tmp/$SERVICE.pid
     echo ".....please wait one moment until $SERVICE is completely started"
     sleep 10
     echo "$(date "+%F %T") - CumulusMX is being Started with Parameter -r (Restart)" >> $LOGPATH 2>&1
     exit
   fi

#### Find out if -s (status) Parameter is to see Status of Cumulus
 if [ "$1" = "-s" ]; then
     NOW=$(date)
     CUMULUSMXONLINE=$(curl -s http://sandaysoft.com/forum/ -o /tmp/version.txt | grep -i "Latest Cumulus MX release" /tmp/version.txt | sed 's/^.*v3.0.0/>v3.0.0/' |cut -c15-18)
     MXVERSIONSHORT=$(find $INSTPATH/MXdiags/*.txt -type f -printf '%T@ %p\n' | sort -n | tail -1 | cut -f2- -d" " |xargs grep "Cumulus MX v" |sed 's/.*\(....\)/\1/')
     SCRIPTVERSIONONLINESHORT=$(wget -q -O- http://bit.ly/1H0ZVUV |grep "SHORTVERSION" |cut -c14-17)
     SCRIPTVERSIONSHORT=$(echo "$VERSION" | cut -d "'" -f2 |cut -d " " -f1 |tr -d '.')
     MONOVERSION=$(mono --version |head -n 1)
     OS=$(cat /etc/*release |grep -i "^NAME=" |cut -d = -f 2)
     OSVERSION=$(cat /etc/*release |grep -i "^VERSION=" |cut -d= -f 2 |xargs $FLAVOUR | tr '[:lower:]' '[:upper:]')
     FLAVOUR=$(cat /etc/*release |grep -i "ID_LIKE=" |cut -d= -f 2 |xargs $FLAVOUR | tr '[:lower:]' '[:upper:]')
     KERNEL=$(uname -r)
     OSLANG=$(locale | grep LANG | cut -d= -f2)
     MXLANG=$(ls -t /$INSTPATH/MXdiags/*.txt | head -1 |xargs grep "Current culture" |cut -d " " -f5)

##### Checking local in Config File ----
    if [ -z "$MXLANGUAGE" ] ; then
       MXLANGU="System Language"
    else
       MXLANGU="$MXLANGUAGE"
    fi

     if [ $MXVERSIONSHORT -lt $CUMULUSMXONLINE ]; then
          MXUPDATEAVAILABLE=""$ALARMCOLOR"Available new Version: v3.0.0 build $CUMULUSMXONLINE"$RESTORE" - "$WARNCOLOR"Please consider to update your CumulusMX"$RESTORE""
     else
          MXUPDATEAVAILABLE=""$GREEN"Available Version: $MXVERSIONONLINE"$RESTORE""
     fi

     if [ $SCRIPTVERSIONSHORT -lt $SCRIPTVERSIONONLINESHORT ]; then
          SCRIPTUPDATEAVAILABLE=""$ALARMCOLOR"Available new Version: "$VERSIONONLINE""$RESTORE""
     else
          SCRIPTUPDATEAVAILABLE="Available Version: "$GREEN"$VERSIONONLINE"$RESTORE""
     fi
     if [  "$CLOUDSERVER" ] ; then
     CLOUDSERVERCONFIGURED="Cloud Backup Server: "$GREEN"$CLOUDSERVER"$RESTORE" - Cloudbackup Folder: "$GREEN"$CLOUDPATH"$RESTORE""
     else
     CLOUDSERVERCONFIGURED="Cloud Backup Settings are not configured"
     fi
     echo -e ""$VIOLET"<<<<<<<<< Cumulus Status at "`date`" >>>>>>>>"$RESTORE"\n"
     echo -e ""$VIOLET"Version check"$RESTORE""
     echo -e "CumulusMX   Version: "$GREEN""$MXVERSION""$RESTORE" - "$MXUPDATEAVAILABLE""
     echo -e "This Script Version: "$GREEN""$VERSION""$RESTORE" - "$SCRIPTUPDATEAVAILABLE""
     echo -e "CumulusNow  Version: "$GREEN"$NOWVERSION"$RESTORE" - Available Version: "$GREEN"$NOWVERSIONONLINE"$RESTORE""
     echo -e "Linux  OS   Version: "$GREEN""$OS" - "$FLAVOUR" - "$OSVERSION" - "$KERNEL""$RESTORE""
     echo -e "Mono Version: "$MONOVERSION""
     echo -e ""$VIOLET"Status check"$RESTORE""
     echo -e "$SERVICE is "$RUNCOLOR"$RUNNING"$RESTORE""
     echo -e "$SERVICE is running since: "$GREEN"$RUNTIME"$RESTORE""
     echo -e "$SERVICE is $REALPORT listening on TCP Port: "$GREEN"$PORT"$RESTORE" (http://$IPADDRESS:$PORT) $REALPORT2"
     echo -e "$SERVICE was started by user: "$GREEN""$PIDOWNER""$RESTORE" - "$SERVICE"-Statuspage was called as: "$GREEN""$WHOAMI""$RESTORE" and locale is: "$GREEN"$MXLANGU"$RESTORE""
     echo -e "ProcessID (PID) of $SERVICE is: "$GREEN"$MONOPID"$RESTORE""
     echo -e ""$VIOLET"Environment check"$RESTORE""
     echo -e "Path to CumulusMX is: "$GREEN"$INSTPATH"$RESTORE""
     echo -e "Path to CumulusMX Backup Folder is: "$GREEN"$BACKUPFOLDER"$RESTORE" - Backups to keep: "$GREEN"$BACKUPTIME"$RESTORE""
     echo -e "Path to CumulusMX DD Backup Folder is: "$GREEN"$DDBACKUPFOLDER"$RESTORE" - Backups to keep: "$GREEN"$DDBACKUPTIME"$RESTORE""
     echo -e "$CLOUDSERVERCONFIGURED"
     echo -e "System Locale: "$GREEN""$OSLANG""$RESTORE" - CumulusMX Language: "$GREEN""$MXLANG""$RESTORE""
     echo -e ""$VIOLET"System check"$RESTORE""
     echo -e "Current System Date/Time is: "$GREEN"$NOW"$RESTORE""
     echo -e "Network Interface: "$GREEN""$INTERFACE""$RESTORE" - IP Address: "$GREEN""$IPADDRESS""$RESTORE" - Netmask: "$GREEN""$NETMASK""$RESTORE""
     echo -e "System Uptime of RasberryPi("$HOSTNAME") is: "$GREEN"$UPTIME"$RESTORE"" # ($PRETTYUPTIME)"
     echo -e "Overall used diskspace of $INSTPATH Folder is: " |tr -d '\n' ; du -sh $INSTPATH ; echo -n "Free diskspace on this device: " ; df -Ph . | tail -1 | awk '{print $4 " of "  $2 " Total, used "  $3}' ; echo -n "Free diskspace on boot device: " ; df / | awk '{print (100 -$5 )}' | tail -1 | sed 's/$/%/g'  ; echo -n "Free diskspace on CumulusMX Install device ("$INSTPATH"): " ; df "$INSTPATH" | awk '{print (100 -$5 )}' | tail -1 | sed 's/$/%/g' ;echo -e ""
     echo "$(date "+%F %T") - CumulusMX Script is being called with -s (Status)" >> $LOGPATH 2>&1
     #DISKALARM#
       if [ "$DISKALARM" == 1 ]; then
          echo -e ""$WARNCOLOR"Warning: Diskusage is at $CURRENT% $RESTORE"
          else
            if [ "$DISKALARM" == 2 ]; then
            echo -e ""$ALARMCOLOR"Disk Space Alert - Your root partition remaining free space is critically low. Used: $CURRENT%" | tee -a $LOGPATH
            fi
       fi
     #END DISKALARM#
     exit
 fi

#### Find out if -q (quit) Parameter is set to quit Cumulus
 if [ "$1" = "-q" ]; then
     printf "\n\033[1m\e[32mStopping Cumulus now\n\n"     echo -e "\033[0m\n"
     screen -X -S "CumulusMX" stuff "^C"
     sleep 5 2>/dev/null
     kill -9 $MONOPID 2>/dev/null
     rm /tmp/$SERVICE.pid 2>/dev/null
     echo "$(date "+%F %T") - System - CumulusMX is being Stopped with -q" >> $LOGPATH 2>&1
     exit 1
 fi
#### Find out if -d (resume detached Screen session) Parameter is set
 if [ "$1" = "-d" ]; then
     echo -e "\nThis Parameter will resume detached $SERVICE\n"
     echo -e "\033[33;7m Resume screened $SERVICE by typing CTRL-A and D \033[0m"
     echo "$(date "+%F %T") - CumulusMX - CumulusMX is being called with -d Option (Detach form Screen)" >> $LOGPATH
     read -p "Press Enter to continue... " -n1 -s
     screen -r -S  $SERVICE
     exit 1
 fi
# Find out if -u (Update) Parameter is set
 if [ "$1" = "-u" ]; then
     if [ ! -f /usr/bin/zip ]; then
     echo - "Sorry, this function needs zip to be installed on your system but you haven't. Pease install zip with <sudo apt-get install zip>"
     read -r -p "Do you want to install zip now? ? [Y/n]" response
     response=${response,,} # tolower
         if [[ $response =~ ^(yes|y| ) ]]; then
             apt-get install zip
             echo -e "\nZip successfully being installed - Please repeat the command again\n"
             exit
         fi
 fi
 echo -e ""$GREEN"This Option will update your CumulusMX Version based on a new CumulusMXDISTxxxx Zip File"$RESTORE"" | tee -a $LOGPATH
 read -e -p "Enter path and filename of the Cumulus Update file - use TAB for Filename completion: " UPDATE

       if file --mime-type "$UPDATE" | grep -q '\.zip'; then
       echo -e "\nI found this file: \c"&&find $UPDATE  -printf "%p - Size: %s Bytes\n\n" | tee -a $LOGPATH
       read -r -p "Do you want to stop $SERVICE and extract $UPDATE into $INSTPATH/ ? [Y/n]" response
       response=${response,,} # tolower
           if [[ $response =~ ^(yes|y| ) ]]; then
              read -e -p "Any folder in the Update Archive file which should not be extracted to $INSTPATH/? Insert name of the folder (example: web ): " OVERRIDE
              echo -e "\nFolder <$OVERRIDE> in the zip  will not be extracted to $INSTPATH/" | tee -a $LOGPATH
              echo -e "\nBeginning with Update of $MXVERSION - File: $UPDATE will be extracted to $INSTPATH/" | tee -a $LOGPATH
              read -p  "Press any key to continue... or CTRL+C to quit" -n 1
              #Stopping Cumulus
              screen -X -S $SERVICE  stuff "^C" 2>/dev/null
              sleep 5
              kill -5 $MONOPID 2>/dev/null
              rm /tmp/$SERVICE.pid 2>/dev/null
              RUNNING='not running'
              printf "\e[32m$SERVICE is being stopped - extracting Update File now\n"
              echo -e "\033[0m"
              cp $UPDATE /tmp/cumulusmx_update.zip
              cd /tmp
              #Check if Exclude Folder Variable $OVERRIDE is empty or not
              if [ -z "$OVERRIDE" ]; then
                 unzip /tmp/cumulusmx_update.zip -d $UPDATEPATH
              else
                 zip -d -q cumulusmx_update.zip *$OVERRIDE/*
                 unzip /tmp/cumulusmx_update.zip -d $UPDATEPATH
              fi
              rm /tmp/cumulusmx_update.zip
              echo "$(date "+%F %T") - CumulusMX - CumulusMX Update Successfully installed" >> $LOGPATH
              read -r -p "Update successfully installed, do you want to start $SERVICE again ? [Y/n]" response
              response=${response,,} # tolower
                  if [[ $response =~ ^(no|n| ) ]]; then
                    exit
                  else
                    echo "Starting CumulusMX"
                  fi
                    #No need to start Cumulus here, because script will run until end
                  else
                     echo -e "\nFile: $UPDATE will not be installed - Aboarding installation" | tee -a $LOGPATH
                     exit
                  fi
            else
               echo -e "\n$UPDATE is not a valid CumulusMX Update file which is commonly shipped in ZIP format - script will exit"&& exit
           fi
    fi

### Find out if Option -l for Logfile viewer
 if [ "$1" = "-l" ]; then
    CURMONTH=$(ls -t $INSTPATH/data/*log.txt | head -1 | rev | cut -d"/" -f1 | rev)
    echo "$(date "+%F %T") - CumulusMX is called with option -l (Logfile viewer)" >> $LOGPATH
    PS3="Please enter your choice: "
    # text for options
     options=("Show MXDiags first 100 lines" "Show MXdiags live-view" "Show FTP-Log live-view" "Show today.ini" "Show $CURMONTH log live-view" "Show alltime.ini" "Show <Data input errors>" "List Backup Folder Contents" "Show Weather Station Values" "List Variables" "Show cumulusmxsh.log" "Quit")
     echo -e "\n"
     select option in "${options[@]}"
 do
   case $option in
      "Show MXDiags first 100 lines")
         echo "Showing first 100 lines of the most current MXDiag logfile"
         read -p "Press Enter to continue... (or wait 10 seconds to automatically proceed with MXdiags Logfile)" -n 1 -t 10
         ls -t $INSTPATH/MXdiags/*.txt | head -1 |xargs head -n100 |more;;
      "Show MXdiags live-view")
         echo -e "\nShowing Live view of the most current MXDiag logfile - Press CTRL+C to leave"
         read -p "Press Enter to continue... (or wait 10 seconds to automatically proceed with MXdiags Logfile)" -n 1 -t 10
         ls -t $INSTPATH/MXdiags/*.txt | head -1 |xargs tail -f;;
      "Show FTP-Log live-view")
         echo -e "\nShowing FTP Logfile - Live view - Press CTRL+C to leave\n"
         tail -f /$INSTPATH/ftplog.txt;;
      "Show today.ini")
         echo -e "\nFile last updated"
         date -r  /$INSTPATH/data/today.ini
         read -p "Press Enter to continue... "
         more /$INSTPATH/data/today.ini
         ;;
      "Show $CURMONTH log live-view")
         ls -t $INSTPATH/data/*log.txt | head -1 |cut -d " " -f10 |xargs tail -f
         ;;
      "Show alltime.ini")
         echo -e "\033[0m"
         echo "File last updated"
         date -r  /$INSTPATH/data/alltime.ini
         read -p "Press Enter to continue... "
         more /$INSTPATH/data/alltime.ini
         ;;
      "Show <Data input errors>")
       grep "Data input appears to have stopped" /$INSTPATH/MXdiags/*.txt |more
         ;;
      "List Backup Folder Contents")
        ls -ltr $BACKUPFOLDER $DDBACKUPFOLDER
         ;;
      "Show Weather Station Values")
          TEMP=$(cat $INSTPATH/graphconfig.json |cut -d "\"" -f 6)
          WIND=$(cat $INSTPATH/graphconfig.json |cut -d "\"" -f 14)
          RAIN=$(cat $INSTPATH/graphconfig.json |cut -d "\"" -f 22)
          PRESS=$(cat $INSTPATH/graphconfig.json |cut -d "\"" -f 30)
          VALDATE=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f1)
          VALTIME=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f2)
          VALTEMP=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f3)
          VALHUM=$(ls -t  $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f4)
          VALPRES=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f11)
          VALWIND=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f7)
          VALRAIN=$(ls -t $INSTPATH/data/*log.txt | head -1 | cut -d " " -f10 |xargs tail -n1 |cut -d ";" -f9)
        echo -e "\nCumulus Values "$GREEN"$VALDATE"$RESTORE" at "$GREEN"$VALTIME"$RESTORE"\nOutside Temperature: "$GREEN"$VALTEMP °$TEMP"$RESTORE"\nHumidity: "$GREEN"$VALHUM %"$RESTORE"\nPressure: "$GREEN"$VALPRES $PRESS"$RESTORE"\nWind: "$GREEN"$VALWIND $WIND"$RESTORE"\nRain: "$GREEN"$VALRAIN $RAIN"$RESTORE""
         ;;
      "List Variables")
      echo "This command will show all Variables used in this script. Output is also available in /tmp/cumulusmx_variables.txt"
      grep -E -o '\$\w+' $INSTPATH/cumulusmx.sh |sort |uniq |tee /tmp/cumulusmx_variables.txt
      ;;
      "Show cumulusmxsh.log")
      echo "This command will show the cumulusmxsh.log - cat $LOGPATH"
      more $LOGPATH
      ;;
      "Quit")
         echo "You chose to quit."
         break
         ;;
      *)
         echo "Invalid option"
         ;;
   esac
    echo -e "\n"
   done
    exit
 fi

### Find out if -b (Backup) Parameter is set
 if [ "$1" = "-b" ]; then
     mkdir $BACKUPFOLDER 2>/dev/null
     while getopts ':bztdcl:' OPTION ; do
     case "$OPTION" in
        b) echo -e "\nYou are about to create a backup of $SERVICE ($MXVERSION). Available parameters are:  -z = zip| -t = tgz| -d = dd | -c = Cloud-WebDAV";;
        z) if [ -f /usr/bin/zip ]; then
              echo "$(date "+%F %T") - ZIP Backup Create a zip backup from $INSTPATH into folder $BACKUPFOLDER" | tee -a $LOGPATH
              read -p "Press Enter to continue... (or wait 10 seconds to automatically proceed with backup)" -n 1 -t 10
              echo ""
              zip -r $BACKUPFOLDER/$(date +%F_%H%M)_$SERVICE.zip $INSTPATH -x "*MXdiags*"
              echo -e "\nBackup successully created in $BACKUPFOLDER"
              echo "$(date "+%F %T") - ZIP Backup - $BACKUPFOLDER$(date +%F_%H%M)_$SERVICE.zip successfully created" >> $LOGPATH 2>&1
                  if [ -z "$BACKUPTIME" ]; then
                     echo "Variable BACKUPTIME is not defined cumulusmxsh.conf - Will not delete any old tar.gz backup files" | tee -a $LOGPATH
                     exit
                  else
                     COUNT=$(ls -al $BACKUPFOLDER/*_$SERVICE.zip |wc -l)
                     RESULT=$(($BACKUPTIME - $COUNT))
                        if [ $RESULT -lt 0 ];then
                           echo -e "Now $COUNT of configured $BACKUPTIME backup files exist - 1 (the oldest) Backup file will be deleted" | tee -a $LOGPATH
                           cd $BACKUPFOLDER
                           read -p  "Press any key to continue... or CTRL+C to quit (or wait 10 seconds to automatically delete these backups)" -n 1 -t 10
                           (ls -t *_$SERVICE.zip|head -n $BACKUPTIME;ls)|sort|uniq -u|xargs rm
                        else
                           echo -e "Now $COUNT of $BACKUPTIME backup files exist - remaining Backup files: $RESULT - nothing to delete" | tee -a $LOGPATH
                        fi
                  fi
            else
                if [ ! -f /usr/bin/zip ]; then
                echo - "Sorry, this function needs zip to be installed on your system but you haven't. Pease install zip with <sudo apt-get install zip>"
                read -r -p "Do you want to install zip now? ? [Y/n]" response
                response=${response,,} # tolower
                  if [[ $response =~ ^(yes|y| ) ]]; then
                   apt-get install zip
                   echo -e "\nZip successfully being installed - Please repeat the command again\n" | tee -a $LOGPATH
                   exit
                 fi
               fi
               exit
              fi;;
        t) echo -e "$(date "+%F %T") - TGZ Backup - Create a tar.gz backup from $INSTPATH into folder $BACKUPFOLDER\n" | tee -a $LOGPATH
             read -p  "Press any key to continue... (or wait 10 seconds to automatically proceed with backup)" -n 1 -t 10
             echo ""
             tar cfvz $BACKUPFOLDER/$(date +%F_%H%M)_$SERVICE.tar.gz $INSTPATH/ --exclude=MXdiags
             echo "Backup successully created in $BACKUPFOLDER"
             echo "$(date "+%F %T") - TGZ Backup - $BACKUPFOLDER$(date +%F_%H%M)_$SERVICE.tar.gz successfully created" >> $LOGPATH 2>&1
             if [ -z "$BACKUPTIME" ]; then
               echo "Variable BACKUPTIME is not defined in cumulusmxsh.conf - Will not delete any old tar.gz backup files" | tee -a $LOGPATH
               exit
              else
                 COUNT=$(ls -al $BACKUPFOLDER/*.tar.gz |wc -l)
                 RESULT=$(($BACKUPTIME - $COUNT))
                 if [ $RESULT -lt 0 ];then
                    echo -e "Now $COUNT of configured $BACKUPTIME backup files exist - 1 (the oldest) Backup file will be deleted" | tee -a $LOGPATH
                    cd $BACKUPFOLDER
                    read -p  "Press any key to continue... or CTRL+C to quit (or wait 10 seconds to automatically delete these backups" -n 1 -t 10
                    (ls -t *.tar.gz|head -n $BACKUPTIME;ls)|sort|uniq -u|xargs rm
                 else
                 echo -e "Now $COUNT of $BACKUPTIME backup files exist - remaining Backup files: $RESULT - nothing to delete" | tee -a $LOGPATH
                 fi
             fi;;
        d) echo -e "\nCreate a dd image of your SD-Card into folder $DDBACKUPFOLDER - Depending on the size of your SD-Card/Device,"
           echo -e "this can take some "$ALARMCOLOR"minutes up to 1 hour"$RESTORE" and no progress bar is being displayed. You can check the progress by looking into the backup destination directory frequently"
           echo -e "For example: If you have a 4 GB SD Card, the Backup file will also be 4 GB"
           echo -e "\n"$ALARMCOLOR"Please make sure, that the DD Backup destination is located on a mounted network drive or external drive!"$RESTORE""
           echo -e "Currently the DD Backup folder is set to:"$GREEN" $DDBACKUPFOLDER"$RESTORE"\n"
             if [ "$(whoami)" != "root" ]; then
              echo -e "\n\n"$ALARMCOLOR"   Sorry, insufficient rights to create a DD Backup. You need to have ROOT permissions. Please start with "$GREEN"sudo "$INSTPATH"/cumulusmx.sh -b -d"$RESTORE"\n\n"
              exit
             fi

             if [ -z "$DDBACKUPFOLDER" ]; then
                 echo -e "\n\\033[31;1mThe DD BACKUPFOLDER Variable <DDBACKUPFOLDER> is not defined in the cumulusmxsh.ini. Please define and repeat command\nPlease make sure, this folder is located on a remote Device"
                 exit
             else
                 read -p  "Press any key to continue...CTRL+C to break (or wait 30 seconds to automatically proceed with dd backup)" -n 1 -t 30
                 echo -e "\n"$GREEN"Backup is starting now. The last $DDBACKUPTIME DD_Backup Files will remain"$RESTORE"\n......Backup in progress ...please be patient....\n"
                 dd if=/dev/mmcblk0 of=$DDBACKUPFOLDER/$(date +%F)_$SERVICE.img bs=1MB
                 echo -e "\nDD Backup file "$(date +%F)_$SERVICE.img" successully created in $DDBACKUPFOLDER"
                 echo "$(date "+%F %T") - DD Backup - $DDBACKUPFOLDER/$(date +%F)_$SERVICE.img successfully created" >> $LOGPATH 2>&1
             fi
             if [ -z "$DDBACKUPTIME" ]; then
             echo "Variable DDBACKUPTIME is not defined in cumulusmxsh.conf - Will not delete any old DD Backup files"
             exit
             else
             echo -e "\nNow the oldest backup file will be deleted. All dd backup files older than the last $DDBACKUPTIME backups"
             cd $DDBACKUPFOLDER
             read -p  "Press any key to continue... or CTRL+C to quit (or wait 10 seconds to automatically delete these backups)" -n 1 -t 10
             (ls -t *_$SERVICE.img |head -n $DDBACKUPTIME;ls *.img) |sort |uniq -u |xargs rm
             fi;;
          c) if [ -f /usr/bin/zip ]; then
                if [[ $CLOUDUSER == *[@]* || $CLOUDPASS == *[@]* ]]
                  then
                    echo -e "\n$(date "+%F %T") - "$ALARMCOLOR"Found @ character in WebDAV username or password"$RESTORE"\n"$WARNCOLOR"In case username or password contains an @ sign, please use "%40" instead (user@gmail.com ---> user%40gmail.com"$RESTORE"" | tee -a $LOGPATH
                exit
                fi
              CLOUDDATE="$(date +%F_%H%M)"
              echo "$(date "+%F %T") - Cloud-WebDAV  Backup - Create a zip backup of "$INSTPATH" and upload it to $CLOUDPROTO://$CLOUDSERVER/$CLOUDPATH/"$CLOUDDATE"_"$SERVICE".zip" | tee -a $LOGPATH
              read -p "Press Enter to continue... (or wait 20 seconds to automatically proceed with backup)" -n 1 -t 20
              echo ""
              zip -r /tmp/"$CLOUDDATE"_"$SERVICE".zip $INSTPATH -x "*MXdiags*"
              curl -S -m $CLOUDUPTIMEOUT -T /tmp/"$CLOUDDATE"_"$SERVICE".zip $CLOUDPROTO://$CLOUDUSER:$CLOUDPASS@$CLOUDSERVER/$CLOUDPATH/ > /dev/null | tee -a $LOGPATH
              rm /tmp/"$CLOUDDATE"_"$SERVICE".zip
              echo -e "$(date "+%F %T") - Backup successully created and copied to $CLOUDPROTO://$CLOUDSERVER/$CLOUDPATH/"$CLOUDDATE"_$SERVICE.zip" | tee -a $LOGPATH
            else
                if [ ! -f /usr/bin/zip ]; then
                echo - "Sorry, this function needs zip to be installed on your system but you haven't. Pease install zip with <sudo apt-get install zip>"
                read -r -p "Do you want to install zip now? ? [Y/n]" response
                response=${response,,} # tolower
                  if [[ $response =~ ^(yes|y| ) ]]; then
                   apt-get install zip
                   echo -e "\nZip successfully being installed - Please repeat the command again\n" | tee -a $LOGPATH
                   exit
                 fi
               fi
               exit
              fi;;
          *) echo "Unknown parameter $1 $2 - Please try -t , -z or -d or use ./cumulusmx -h for help"
          esac
          done
          exit
        fi

### Watchdog Mode
     if [ "$1" = "-w" ]; then
        if [ -f /tmp/$SERVICE.pid ]; then
           exit
        else
           echo "$(date "+%F %T") - Watchdog Mode - $SERVICE will be started by Cron now" >> $LOGPATH
        fi
     fi
### End Watchdog


################## Beginning of Script when called without Parameters


#### Find out if CumulusMX is already "screened" and check if it should be stopped #
 if screen -ls | grep -v grep | grep $SERVICE > /dev/null
    then
    RUNTIME=$(find /tmp/$SERVICE.pid -maxdepth 0 -printf "%TY-%Tm-%Td %TH:%TM\n") > /dev/null
    echo -e "\n$RUNCOLOR<<<<<<<<< Cumulus Status >>>>>>>>$RESTORE"
    echo -e "\033[0m"
    echo -e "$SERVICE is $RUNCOLOR$RUNNING${RESTORE} ($MXVERSION)\n$SERVICE is $REALPORT listening on TCP Port: $PORT (http://$IPADDRESS:$PORT)\nProcessID (PID) of $SERVICE is: $MONOPID\nCumulusMX Version is: $MXVERSION\nSystem Uptime of $HOSTNAME is: $UPTIME\n$SERVICE is running since: $RUNTIME\nPath to CumulusMX is: $INSTPATH\n"
    read -r -p "Do you want to stop $SERVICE ? [Y/n]" response
    response=${response,,} # tolower
       if [[ $response =~ ^(yes|y| ) ]]; then
          screen -X -S $SERVICE  stuff "^C"
          sleep 5
          kill -5 $MONOPID 2>/dev/null
          rm /tmp/$SERVICE.pid
          printf "\e[31m$SERVICE is being stopped\n"
          echo -e "\033[0m"
       fi

### If CumulusMX is not running - starting CumulusMX
    else
    ### Check if Script is called with another TCP Port ###
    if [ "$1" = "-p" ]; then
       case $2 in
       ''|*[!0-9]*) echo "Number is not a valid TCP Port - try 1-65535" ;;
       *) PORT=$2 ;;
       esac
    fi
    ### END TCP PORT ###

### Check if system is currently booted
       upSeconds="$(cat /proc/uptime | grep -o '^[0-9]\+')"
       if [ "${upSeconds}" -gt "120" ]; then
        JUSTBOOT=0
       else
        JUSTBOOT=1
       fi
    ### End Check if system is just rebooted

    if [ $JUSTBOOT = 1 ] ; then

##### Check if Network is up and running by pinging Google NameServer 8.8.8.8
     if [ $NETWORKFAILCOUNT = 0 ] ;then
        NETWORKFAILCOUNT=10000
        echo "wait forever"
     fi
 NETWORKFAIL=0
 NETWORK=0
     while [ $NETWORK -lt 1 ]
     do
     ping -c 1 8.8.8.8 > /dev/null 2>&1
      if [ $? -eq 0 ]; then
         NETWORK=$((NETWORK+1))
      else
       echo "$(date "+%F %T") - Network Failure - Unable to reach 8.8.8.8 - Waiting 60 seconds before retry. Max Attempts "$NETWORKFAILCOUNT" x 60 seconds. "$NETWORKFAIL" of "$NETWORKFAILCOUNT" retries. "| tee -a $LOGPATH
       sleep 60
       NETWORKFAIL=$((NETWORKFAIL+1))
      if [ $NETWORKFAIL = $NETWORKFAILCOUNT ];then
        if [ $NETWORKFAILOVER = 0 ]; then
       echo "$(date "+%F %T") - Network Failure - Unable to reach Internet/Network - Quit Start of CumulusMX" >> $LOGPATH 2>&1
           exit
        fi
       echo "$(date "+%F %T") - Network Failure - Unable to reach Internet/Network - Based on Configuration (NETWORKFAILOVER = 1) Continue starting CumulusMX without Network" >> $LOGPATH 2>&1
       NETWORK=1
      fi
     fi
    done
   fi
#####  End checking if network is up directly after reboot


     echo -e "$SERVICE is $RUNCOLOR$RUNNING$RESTORE...trying to start CumulusMX now"
     cd $INSTPATH
     echo "$(date "+%F %T") - CumulusMX trying to start with these parameters $INSTPATH/CumulusMX.exe -port $PORT $MXLANGUAGE" >> $LOGPATH 2>&1
     screen -dmS $SERVICE -amds bash mono $INSTPATH/CumulusMX.exe -port $PORT $MXLANGUAGE
     screen -ls | grep -v grep | grep $SERVICE > /dev/null
     MONOPID=$(pgrep mono && echo)
     echo $MONOPID > /tmp/$SERVICE.pid
     echo -e "\n$RUNCOLOR<<<<<<<<< Cumulus Status >>>>>>>>$RESTORE"
     echo -e "\033[0m"
     echo -e "Starting $SERVICE now\n$SERVICE is listening on TCP Port: "$GREEN"$PORT"$RESTORE" (http://$IPADDRESS:$PORT)\nProcessID (PID) of $SERVICE is "$GREEN"$MONOPID"$RESTORE"\nCumulusMX Version is "$GREEN"$MXVERSION"$RESTORE"\nSystem Uptime of $HOSTNAME is: "$GREEN"$UPTIME"$RESTORE"\nPath to CumulusMX is "$GREEN"$INSTPATH"$RESTORE"\n"

#### DISKALARM#
         if [ "$DISKALARM" == 1 ]; then
            echo -e ""$WARNCOLOR"Warning: Diskusage is at $CURRENT% $RESTORE" >> $LOGPATH
         else
            if [ "$DISKALARM" == 2 ]; then
            echo -e ""$ALARMCOLOR"Disk Space Alert - Your root partition remaining free space is critically low. Used: $CURRENT%" >> $LOGPATH
            fi
         fi
##### END DISKALARM#
     printf "\e[33m$SERVICE is about to start. Please give $SERVICE some seconds to start and check status with sudo ./cumulusmx.sh -s (status)\n"

echo -ne "\n\n"$ALARMCOLOR"     [C                          ]  (5%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cu                         ]  (10%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cum                        ]  (15%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cumu                       ]  (20%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cumul                      ]  (25%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cumulu                     ]  (30%)\r"$RESTORE""
sleep 1
echo -ne ""$ALARMCOLOR"     [Cumulus                    ]  (35%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusM                   ]  (40%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX                  ]  (45%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX i                ]  (50%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX is               ]  (55%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX is j             ]  (60%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX is ju            ]  (65%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX is jus           ]  (70%)\r"$RESTORE""
sleep 1
echo -ne ""$VIOLET"     [CumulusMX is just          ]  (75%)\r"$RESTORE""
sleep 1
echo -ne ""$WARNCOLOR"     [CumulusMX is just s        ]  (80%)\r"$RESTORE""
sleep 1
echo -ne ""$WARNCOLOR"     [CumulusMX is just st       ]  (85%)\r"$RESTORE""
sleep 1
echo -ne ""$WARNCOLOR"     [CumulusMX is just sta      ]  (90%)\r"$RESTORE""
sleep 1
echo -ne ""$WARNCOLOR"     [CumulusMX is just star     ]  (95%)\r"$RESTORE""
sleep 1
echo -ne ""$WARNCOLOR"     [CumulusMX is just start    ]  (99%)\r"$RESTORE""
sleep 1
echo -ne ""$GREEN"     [ !! CumulusMX is started!! ]  (100%)\r"$RESTORE""
sleep 1
echo -ne ""$GREEN"     [                           ]  (100%)\r"$RESTORE""
sleep 1
echo -ne ""$GREEN"     [ !! CumulusMX is started!! ]  (100%)\r"$RESTORE""
sleep 1
echo -ne ""$GREEN"     [                           ]  (100%)\r"$RESTORE""
sleep 1
echo -ne ""$GREEN"     [ !! CumulusMX is started!! ]  (100%)\r"$RESTORE""
echo -ne '\n\n'
echo "$(date "+%F %T") - System - CumulusMX is successfully being started" >> $LOGPATH 2>&1
   fi


exit

# End

